pub struct GarbledChannel { /* private fields */ }Expand description
Type for writing and reading a garbled circuit from memory.
A GarbledChannel provides a way to use the [Channel] interface to
write a garbled circuit to memory, alongside the ability to read it from
memory for evaluation.
A GarbledChannel can be instantiated in one of two ways: either by
calling GarbledChannel::new_writer to store the garbled circuit in
memory, or GarbledChannel::from on an existing GarbledCircuit to
evaluate the garbled circuit.
Note that a GarbledChannel cannot be both a writer and a reader. For
example, calling GarbledChannel::finish_writing on a GarbledChannel
reader results in a panic.
Implementations
Sourceimpl GarbledChannel
impl GarbledChannel
Sourcepub fn new_writer(ngates: Option<usize>) -> Self
pub fn new_writer(ngates: Option<usize>) -> Self
Construct a new GarbledChannel for writing a garbled circuit.
Sourcepub fn finish_writing(self) -> Vec<U8x16>
pub fn finish_writing(self) -> Vec<U8x16>
Consume the GarbledChannel, outputting the resulting garbled circuit.
Panics
Panics if there is no valid writer for the GarbledChannel.