pub struct GarbledCircuit { /* private fields */ }Expand description
A garbled circuit.
A garbled circuit at its core is just a vector of garbled rows and constant wirelabels.
Implementations
Sourceimpl GarbledCircuit
impl GarbledCircuit
Sourcepub fn new(blocks: Vec<U8x16>) -> Self
pub fn new(blocks: Vec<U8x16>) -> Self
Create a GarbledCircuit from a vector of garbled rows and constant
wirelabels.
Sourcepub fn size(&self) -> usize
pub fn size(&self) -> usize
The number of garbled rows and constant wires in the garbled circuit.
Sourcepub fn garble<Wire: WireLabel, Circuit: EvaluableCircuit<Garbler<RNG, Wire>>, RNG: CryptoRng + RngCore>(
c: &Circuit,
rng: RNG,
) -> Result<(Encoder<Wire>, Self, OutputMapping)>
pub fn garble<Wire: WireLabel, Circuit: EvaluableCircuit<Garbler<RNG, Wire>>, RNG: CryptoRng + RngCore>( c: &Circuit, rng: RNG, ) -> Result<(Encoder<Wire>, Self, OutputMapping)>
Garble a circuit.
This outputs three things:
- An
Encoderfor encoding inputs to valid input wirelabels. - The garbled circuit itself.
- An
OutputMappingmapping for mapping output wirelabels to their associated underlying values.
Sourcepub fn eval<Wire: WireLabel, Circuit: EvaluableCircuit<Evaluator<Wire>>>(
&self,
c: &Circuit,
garbler_inputs: &[Wire],
evaluator_inputs: &[Wire],
) -> Result<Vec<u16>>
pub fn eval<Wire: WireLabel, Circuit: EvaluableCircuit<Evaluator<Wire>>>( &self, c: &Circuit, garbler_inputs: &[Wire], evaluator_inputs: &[Wire], ) -> Result<Vec<u16>>
Evaluate the garbled circuit on the provided inputs.
Sourcepub fn eval_to_wirelabels<Wire: WireLabel, Circuit: EvaluableCircuit<Evaluator<Wire>>>(
&self,
c: &Circuit,
garbler_inputs: &[Wire],
evaluator_inputs: &[Wire],
) -> Result<Vec<Wire>>
pub fn eval_to_wirelabels<Wire: WireLabel, Circuit: EvaluableCircuit<Evaluator<Wire>>>( &self, c: &Circuit, garbler_inputs: &[Wire], evaluator_inputs: &[Wire], ) -> Result<Vec<Wire>>
Evaluate the garbled circuit on the provided inputs, returning the output wirelabels.